@@ -78,10 +78,10 @@ time_t now;
 int entries, lflag, mflag, pplan, sflag;
 char tbuf[1024];
 
-#if IPSEC
+#if NETSEC
 void *request = NULL;
 int requestlen = 0;
-#endif /* IPSEC */
+#endif /* NETSEC */
 
 static void loginlist __P((void));
 static void userlist __P((int, char **));
@@ -93,11 +93,11 @@ main(argc, argv)
 {
 	int ch;
 
-#if IPSEC
+#if NETSEC
 	while ((ch = getopt(argc, argv, "lmpsS:")) != EOF)
-#else /* IPSEC */
+#else /* NETSEC */
 	while ((ch = getopt(argc, argv, "lmps")) != EOF)
-#endif /* IPSEC */
+#endif /* NETSEC */
 		switch(ch) {
 		case 'l':
 			lflag = 1;		/* long format */
@@ -111,22 +111,22 @@ main(argc, argv)
 		case 's':
 			sflag = 1;		/* short format */
 			break;
-#if IPSEC
+#if NETSEC
 		case 'S':
-                        if (nrl_strtoreq(optarg, &request, &requestlen)) {
-                          fprintf(stderr, "finger: nrl_strtoreq(%s) failed\n", optarg);
+                        if (netsec_strtoreq(optarg, &request, &requestlen)) {
+                          fprintf(stderr, "finger: netsec_strtoreq(%s, ...) failed\n", optarg);
                           exit(1);
                         };
 			break;
-#endif /* IPSEC */
+#endif /* NETSEC */
 		case '?':
 		default:
 			(void)fprintf(stderr,
-#if IPSEC
+#if NETSEC
 			    "usage: finger [-lmps] [-S security_request] [login ...]\n");
-#else /* IPSEC */
+#else /* NETSEC */
 			    "usage: finger [-lmps] [login ...]\n");
-#endif /* IPSEC */
+#endif /* NETSEC */
 			exit(1);
 		}
 	argc -= optind;
