@@ -63,9 +63,9 @@ jmp_buf	jabort;
 char   *mname;
 char   *home = "/";
 
-#if linux
+#if defined(__linux__) && !defined(__GLIBC__)
 typedef void (*sig_t)(int);
-#endif /* linux */
+#endif /* defined(__linux__) && !defined(__GLIBC__) */
 
 /*
  * `Another' gets another argument, and stores the new argc and argv.
@@ -541,11 +541,11 @@ mput(argc, argv)
 		}
 
 		memset(&gl, 0, sizeof(gl));
-#ifdef GLOB_BRACE
+#if defined(GLOB_BRACE) && defined(GLOB_QUOTE) && defined(GLOB_TILDE)
 		flags = GLOB_BRACE|GLOB_NOCHECK|GLOB_QUOTE|GLOB_TILDE;
-#else /* GLOB_BRACE */
+#else /* defined(GLOB_BRACE) && defined(GLOB_QUOTE) && defined(GLOB_TILDE) */
 		flags = GLOB_NOCHECK;
-#endif /* GLOB_BRACE */
+#endif /* defined(GLOB_BRACE) && defined(GLOB_QUOTE) && defined(GLOB_TILDE) */
 		if (glob(argv[i], flags, NULL, &gl) || gl.gl_pathc == 0) {
 			warnx("%s: not found", argv[i]);
 			globfree(&gl);
@@ -1629,11 +1629,11 @@ globulize(cpp)
 	if (!doglob)
 		return (1);
 
-#ifdef GLOB_BRACE
+#if defined(GLOB_BRACE) && defined(GLOB_QUOTE) && defined(GLOB_TILDE)
 	flags = GLOB_BRACE|GLOB_NOCHECK|GLOB_QUOTE|GLOB_TILDE;
-#else /* GLOB_BRACE */
+#else /* defined(GLOB_BRACE) && defined(GLOB_QUOTE) && defined(GLOB_TILDE) */
 	flags = GLOB_NOCHECK;
-#endif /* GLOB_BRACE */
+#endif /* defined(GLOB_BRACE) && defined(GLOB_QUOTE) && defined(GLOB_TILDE) */
 	memset(&gl, 0, sizeof(gl));
 	if (glob(*cpp, flags, NULL, &gl) ||
 	    gl.gl_pathc == 0) {
@@ -2083,7 +2083,7 @@ restart(argc, argv)
 		printf("restart: offset not specified\n");
 	else {
 		restart_point = atol(argv[1]);
-		printf("restarting at %qd. %s\n", restart_point,
+		printf("restarting at %ld. %s\n", restart_point,
 		    "execute get, put or append to initiate transfer");
 	}
 }
