@@ -54,9 +54,6 @@ static char sccsid[] = "@(#)ftp.c	8.6 (Berkeley) 10/27/94";
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
-#if INET6
-#include <netinet6/in6.h>
-#endif /* INET6 */
 #include <arpa/inet.h>
 #include <arpa/ftp.h>
 #include <arpa/telnet.h>
@@ -83,14 +80,9 @@ static char sccsid[] = "@(#)ftp.c	8.6 (Berkeley) 10/27/94";
 extern int h_errno;
 
 #if INET6
-#define su union { \
-  struct sockaddr sa; \
-  struct sockaddr_in sin; \
-  struct sockaddr_in6 sin6; \
-}
-su hisctladdr;
-su data_addr;
-su myctladdr;
+union sockaddr_union hisctladdr;
+union sockaddr_union data_addr;
+union sockaddr_union myctladdr;
 #else /* INET6 */
 struct	sockaddr_in hisctladdr;
 struct	sockaddr_in data_addr;
@@ -151,8 +143,10 @@ hookup(host, port)
 #else /* NETSEC */
   s = inner_connect(ai, NULL, 0, NULL, NULL, "ftp", &ai2);
 #endif /* NETSEC */
-  if (s >= 0)
+  if (s >= 0) {
     strcpy(hostname = hostnamebuf, ai2->ai_canonname);
+    memcpy(&hisctladdr, ai2->ai_addr, ai2->ai_addrlen);
+  };
   freeaddrinfo(ai);
 
   if (s < 0)
@@ -1271,11 +1265,13 @@ noport:
 		goto bad;
 	      }
 	      result = command("SPORT %s", buffer);
+#if 0
 	      if (result == ERROR && sendport == -1) {
 		sendport = 0;
 		tmpno = 1;
 		goto noport;
 	      }
+#endif /* 0 */
 	      if (result == COMPLETE) {
 		howport = 1;
 		return 0;
@@ -1289,11 +1285,13 @@ noport:
 		  goto bad;
 		}
 		result = command("PORT %s", buffer);
+#if 0
 		if (result == ERROR && sendport == -1) {
 			sendport = 0;
 			tmpno = 1;
 			goto noport;
 		}
+#endif /* 0 */
 		if (result == COMPLETE) {
 		  howport = 2;
 		  return 0;
@@ -1318,6 +1316,11 @@ noport:
 	    default:
 	      return 1;
 	  }
+          if (result == ERROR && sendport == -1) {
+            sendport = 0;
+            tmpno = 1;
+            goto noport;
+          };
 #else /* INET6 */
 		a = (char *)&data_addr.sin_addr;
 		p = (char *)&data_addr.sin_port;
@@ -1360,7 +1363,7 @@ dataconn(lmode)
 	char *lmode;
 {
 #if INET6
-  su from;
+        union sockaddr_union from;
 #else /* INET6 */
 	struct sockaddr_in from;
 #endif /* INET6 */
@@ -1451,8 +1454,8 @@ pswitch(flag)
 		int connect;
 		char name[MAXHOSTNAMELEN];
 #if INET6
-	        su mctl;
-	        su hctl;
+	        union sockaddr_union mctl;
+	        union sockaddr_union hctl;
 #else /* INET6 */
 		struct sockaddr_in mctl;
 		struct sockaddr_in hctl;
