@@ -59,7 +59,7 @@ static char sccsid[] = "@(#)main.c	8.6 (Berkeley) 10/9/94";
 #include <stdlib.h>
 #include <unistd.h>
 
-#if IPSEC
+#if NETSEC
 #include <string.h>
 
 void *control_request = NULL;
@@ -67,7 +67,7 @@ int control_requestlen = 0;
 
 void *data_request = NULL;
 int data_requestlen = 0;
-#endif /* IPSEC */
+#endif /* NETSEC */
 
 #include "ftp_var.h"
 
@@ -89,11 +89,11 @@ main(argc, argv)
 	interactive = 1;
 	autologin = 1;
 
-#if IPSEC
+#if NETSEC
 	while ((ch = getopt(argc, argv, "dgintvS:")) != EOF) {
-#else /* IPSEC */
+#else /* NETSEC */
 	while ((ch = getopt(argc, argv, "dgintv")) != EOF) {
-#endif /* IPSEC */
+#endif /* NETSEC */
 		switch (ch) {
 		case 'd':
 			options |= SO_DEBUG;
@@ -120,7 +120,7 @@ main(argc, argv)
 			verbose++;
 			break;
 
-#if IPSEC
+#if NETSEC
 		case 'S':
 		  {
 		    char *c;
@@ -144,15 +144,15 @@ main(argc, argv)
 		    };
 		  };
 		  break;
-#endif /* IPSEC */
+#endif /* NETSEC */
 
 		default:
 			(void)fprintf(stderr,
-#if IPSEC
+#if NETSEC
 				"usage: ftp [-dgintv] [-S control[,data]] [host [port]]\n");
-#else /* IPSEC */
+#else /* NETSEC */
 				"usage: ftp [-dgintv] [host [port]]\n");
-#endif /* IPSEC */
+#endif /* NETSEC */
 			exit(1);
 		}
 	}
