@@ -62,9 +62,6 @@ static char sccsid[] = "@(#)ftpd.c	8.5 (Berkeley) 4/28/95";
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
-#if INET6
-#include <netinet6/in6.h>
-#endif /* INET6 */
 
 #define	FTP_NAMES
 #include <arpa/ftp.h>
@@ -108,17 +105,11 @@ extern	off_t restart_point;
 extern	char cbuf[];
 
 #if INET6
-#define su union { \
-  struct sockaddr sa; \
-  struct sockaddr_in sin; \
-  struct sockaddr_in6 sin6; \
-}
-
-su ctrl_addr;
-su data_source;
-su data_dest;
-su his_addr;
-su pasv_addr;
+union sockaddr_union ctrl_addr;
+union sockaddr_union data_source;
+union sockaddr_union data_dest;
+union sockaddr_union his_addr;
+union sockaddr_union pasv_addr;
 #else /* INET6 */
 struct	sockaddr_in ctrl_addr;
 struct	sockaddr_in data_source;
@@ -989,7 +980,7 @@ dataconn(name, size, mode)
 		(void) strcpy(sizebuf, "");
 	if (pdata >= 0) {
 #if INET6
-	  su from;
+                union sockaddr_union from;
 #else /* INET6 */
 		struct sockaddr_in from;
 #endif /* INET6 */
@@ -1035,11 +1026,11 @@ dataconn(name, size, mode)
 	file = getdatasock(mode);
 	if (file == NULL) {
 #if INET6
-	  char addr[NI_MAXHOST], port[NI_MAXSERV];
-	  if (getnameinfo((struct sockaddr *)&data_source, NRL_SA_LEN((struct sockaddr *)&data_source), addr, sizeof(addr), port, sizeof(port), NI_NUMERICHOST | NI_NUMERICSERV))
+	  char addr[NI_MAXHOST], service[NI_MAXSERV];
+	  if (getnameinfo((struct sockaddr *)&data_source, NRL_SA_LEN((struct sockaddr *)&data_source), addr, sizeof(addr), service, sizeof(service), NI_NUMERICHOST | NI_NUMERICSERV))
 	    reply(425, "Can't create data socket: %s.");
 	  else
-	    reply(425, "Can't create data socket (%s,%s): %s.", addr, port, strerror(errno));
+	    reply(425, "Can't create data socket (%s,%s): %s.", addr, service, strerror(errno));
 #else /* INET6 */
 		reply(425, "Can't create data socket (%s,%d): %s.",
 		    inet_ntoa(data_source.sin_addr),
@@ -1267,7 +1258,7 @@ void
 statcmd()
 {
 #if INET6
-  struct sockaddr *sa;
+        struct sockaddr *sa;
 #else /* INET6 */
 	struct sockaddr_in *sin;
 #endif /* INET6 */
@@ -1278,9 +1269,9 @@ statcmd()
 	printf("     Connected to %s", remotehost);
 #if INET6
         {
-	  char buf[NI_MAXHOST];
-	  if (!getnameinfo((struct sockaddr *)&his_addr, NRL_SA_LEN((struct sockaddr *)&his_addr), buf, sizeof(buf), NULL, 0, NI_NUMERICHOST))
-	    printf(" (%s)", buf);
+	  char host[NI_MAXHOST];
+	  if (!getnameinfo((struct sockaddr *)&his_addr, NRL_SA_LEN((struct sockaddr *)&his_addr), host, sizeof(host), NULL, 0, NI_NUMERICHOST))
+	    printf(" (%s)", host);
         }
 #else /* INET6 */
 	if (!isdigit(remotehost[0]))
