@@ -186,10 +186,6 @@ static char sccsid[] = "@(#)inetd.c	8.4 (Berkeley) 4/13/94";
 #include <sys/resource.h>
 
 #include <netinet/in.h>
-#ifdef INET6
-#include <netinet6/in6.h>
-#include <sys/un.h>
-#endif /* INET6 */
 #include <arpa/inet.h>
 
 #include <errno.h>
@@ -227,15 +223,6 @@ int	toomany = TOOMANY;
 struct	servent *sp;
 int nflag = 0;
 
-#if INET6
-typedef union {
-  struct sockaddr sa;
-  struct sockaddr_in sin;
-  struct sockaddr_in6 sin6;
-  struct sockaddr_un sun;
-} su;
-#endif /* INET6 */
-
 struct	servtab {
 	char	*se_service;		/* name of service */
 	int	se_socktype;		/* type of socket to use */
@@ -254,7 +241,7 @@ struct	servtab {
 	int	se_fd;			/* open descriptor */
 	int	se_type;		/* type */
 #ifdef INET6
-        su      se_ctrladdr;
+        union sockaddr_union se_ctrladdr;
 #else /* INET6 */
 	struct	sockaddr_in se_ctrladdr;/* bound address */
 #endif /* INET6 */
@@ -675,9 +662,7 @@ config(signo)
 			sep->se_fd = -1;
 			continue;
 		}
-#if INET6
-
-#else /* INET6 */
+#if !INET6
 		sp = getservbyname(sep->se_service, sep->se_proto);
 		if (sp == 0) {
 			syslog(LOG_ERR, "%s/%s: unknown service",
@@ -692,7 +677,7 @@ config(signo)
 				close_sep(sep);
 		}
 		sep->se_ctrladdr.sin_len = sizeof (struct sockaddr_in);
-#endif /* INET6 */
+#endif /* !INET6 */
 		if (sep->se_fd == -1)
 			setup(sep);
 	}
@@ -736,7 +721,7 @@ setup(sep)
 {
 	int on = 1;
 
-#ifdef INET6
+#if INET6
 	if ((sep->se_fd = socket(PF_INET6, sep->se_socktype, 0)) < 0) {
 #else /* INET6 */
 	if ((sep->se_fd = socket(PF_INET, sep->se_socktype, 0)) < 0) {
@@ -1161,7 +1146,7 @@ inetd_setproctitle(a, s)
 	int size;
 	char *cp;
 #ifdef INET6
-	su sa;
+	union sockaddr_union sa;
 #else /* INET6 */
 	struct sockaddr_in sin;
 #endif /* INET6 */
@@ -1169,7 +1154,7 @@ inetd_setproctitle(a, s)
 
 	cp = Argv[0];
 #ifdef INET6
-	size = sizeof(su);
+	size = sizeof(sa);
 	if (getpeername(s, (struct sockaddr *)&sa, &size) == 0) {
 	  int i;
 
