@@ -168,9 +168,8 @@ static char sccsid[] = "@(#)ping.c	8.3 (Berkeley) 4/28/95";
 #if INET6
 #include <sys/uio.h>
 
-#include <netinet6/in6.h>
-#include <netinet6/ipv6.h>
-#include <netinet6/icmpv6.h>
+#include <netinet/ipv6.h>
+#include <netinet/icmpv6.h>
 
 #include "support.h"
 #endif /* INET6 */
@@ -578,14 +577,14 @@ main(argc, argv)
         };
 
         {
-	  char buf[64];
+	  char host[NI_MAXHOST];
 
-	  if (getnameinfo((struct sockaddr *)&whereto, NRL_SA_LEN((struct sockaddr *)&whereto), buf, sizeof(buf), NULL, 0, NI_NUMERICHOST)) {
+	  if (getnameinfo((struct sockaddr *)&whereto, NRL_SA_LEN((struct sockaddr *)&whereto), host, sizeof(host), NULL, 0, NI_NUMERICHOST)) {
 	    fprintf(stderr, "ping: getnameinfo failed\n");
 	    exit(1);
 	  }
 
-	  printf("PING %s (%s): %d data bytes\n", hostname, buf, datalen);
+	  printf("PING %s (%s): %d data bytes\n", hostname, host, datalen);
 	}
 #else /* INET6 */
 	if (to->sin_family == AF_INET)
